"use strict";

var fs     = require('fs'),
    crypto = require('crypto');
var _self = {},
    _config = {},
    _instance,
    _callbacks = [];

function init(params){
    if(params !== undefined && params.instance !== undefined && params.start !== undefined && params.end !== undefined && params.run !== undefined){
        _instance = params.instance;
        _callbacks['start']       = params.start;
        _callbacks['end']         = params.end;
        _callbacks['run']         = params.run;
        _callbacks['communicate'] = params.communicate;
        _callbacks['error']       = params.error;
        _callbacks['notify']      = params.notify;

        try{
            _config = JSON.parse(fs.readFileSync(_instance.path + _instance.config));
        }catch(ex){
            return ex;
        }

        if(_config.date)
            _self.time = _config.date.getTime();
        else
            _self.time = new Date().getTime()+10000;
        return _self;
    }
}

_self.run = function(params){
    _self.start({uid: _instance.uid, date: new Date()});
    var results = [];
    for(var i = _config.start; i <= _config.end; i++){
        var element = {
            refer: i,
            hashed: crypto.createHash('md5').update(i.toString()).digest('hex')
        };
        results.push(element);
        if( i != 0 && i % _config.limit == 0){
            _self.communicate({uid: instance.uid, data: results});
            results = [];
        }
    }
    _self.end({uid: _instance.uid, date: new Date()});
};

_self.start = function(params){
    _callbacks['start'](params);
};

_self.end = function(params){
    _callbacks['end'](params);
};

_self.communicate = function(params){
    _callbacks['communicate'](params);
};

_self.notify = function(params){
    _callbacks['notify'](params);
};

module.exports = init;